@@ -1,5 +1,6 @@
 /*
  * Copyright 2014-2016 Canonical Ltd.
+ * Copyright 2021-2022 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -15,12 +16,17 @@
  *
  * Authors:
  *   Charles Kerr <charles.kerr@canonical.com>
+ *   Robert Tari <robert@tari.in>
  */
 
 #include "datafiles.h"
 
-#ifdef HAS_UT_ACCTSERVICE_SYSTEMSOUND_SETTINGS
-#include "dbus-accounts-sound.h"
+#ifdef LOMIRI_FEATURES_ENABLED
+    #include "dbus-accounts-sound.h"
+#endif
+
+#ifndef LOMIRI_SOUNDSDIR
+    #define LOMIRI_SOUNDSDIR ""
 #endif
 
 #include "dbus-battery.h"
@@ -84,7 +90,7 @@ typedef struct
   gboolean actions_supported;
 
   GCancellable * cancellable;
-  #ifdef HAS_UT_ACCTSERVICE_SYSTEMSOUND_SETTINGS
+  #ifdef LOMIRI_FEATURES_ENABLED
   DbusAccountsServiceSound * accounts_service_sound_proxy;
   gboolean accounts_service_sound_proxy_pending;
   #endif
@@ -145,7 +151,7 @@ get_battery_power_level (IndicatorPowerDevice * battery)
 ****  Sounds
 ***/
 
-#ifdef HAS_UT_ACCTSERVICE_SYSTEMSOUND_SETTINGS
+#ifdef LOMIRI_FEATURES_ENABLED
 static void
 on_sound_proxy_ready (GObject      * source_object G_GNUC_UNUSED,
                       GAsyncResult * res,
@@ -307,7 +313,7 @@ notification_show(IndicatorPowerNotifier * self)
 
   if (are_actions_supported(self))
     {
-      #ifdef HAS_UT_ACCTSERVICE_SYSTEMSOUND_SETTINGS
+      #ifdef LOMIRI_FEATURES_ENABLED
       if (!silent_mode(self))
       #endif
         {
@@ -320,14 +326,15 @@ notification_show(IndicatorPowerNotifier * self)
             }
           else
             {
-              g_warning("Unable to find '%s' in XDG data dirs", LOW_BATTERY_SOUND);
+              g_message("Unable to find '%s' in XDG data dirs, falling back to %s/notifications/", LOMIRI_SOUNDSDIR, LOW_BATTERY_SOUND);
+              notify_notification_set_hint(nn, "sound-file", g_variant_new_string("file://" LOMIRI_SOUNDSDIR "/notifications/" LOW_BATTERY_SOUND));
             }
         }
 
-      notify_notification_set_hint(nn, "x-canonical-snap-decisions", g_variant_new_string("true"));
-      notify_notification_set_hint(nn, "x-canonical-non-shaped-icon", g_variant_new_string("true"));
-      notify_notification_set_hint(nn, "x-canonical-private-affirmative-tint", g_variant_new_string("true"));
-      notify_notification_set_hint(nn, "x-canonical-snap-decisions-timeout", g_variant_new_int32(INT32_MAX));
+      notify_notification_set_hint(nn, "x-lomiri-snap-decisions", g_variant_new_string("true"));
+      notify_notification_set_hint(nn, "x-lomiri-non-shaped-icon", g_variant_new_string("true"));
+      notify_notification_set_hint(nn, "x-lomiri-private-affirmative-tint", g_variant_new_string("true"));
+      notify_notification_set_hint(nn, "x-lomiri-snap-decisions-timeout", g_variant_new_int32(INT32_MAX));
       notify_notification_set_timeout(nn, NOTIFY_EXPIRES_NEVER);
       notify_notification_add_action(nn, "dismiss", _("OK"), on_dismiss_clicked, NULL, NULL);
       notify_notification_add_action(nn, "settings", _("Battery settings"), on_battery_settings_clicked, NULL, NULL);
@@ -451,7 +458,7 @@ my_dispose (GObject * o)
   indicator_power_notifier_set_battery (self, NULL);
   g_clear_object (&p->dbus_battery);
 
-  #ifdef HAS_UT_ACCTSERVICE_SYSTEMSOUND_SETTINGS
+  #ifdef LOMIRI_FEATURES_ENABLED
   g_clear_object (&p->accounts_service_sound_proxy);
   #endif
 
@@ -488,7 +495,7 @@ indicator_power_notifier_init (IndicatorPowerNotifier * self)
   if (!instance_count++ && !notify_init(SERVICE_EXEC))
     g_critical("Unable to initialize libnotify! Notifications might not be shown.");
 
-  #ifdef HAS_UT_ACCTSERVICE_SYSTEMSOUND_SETTINGS
+  #ifdef LOMIRI_FEATURES_ENABLED
   p->accounts_service_sound_proxy_pending = TRUE;
   gchar* object_path = g_strdup_printf("/org/freedesktop/Accounts/User%lu", (gulong)getuid());
   dbus_accounts_service_sound_proxy_new_for_bus(
