@@ -1,6 +1,6 @@
 /*
  * Copyright 2013-2016 Canonical Ltd.
- * Copytight 2021 AyatanaIndicators
+ * Copyright 2021 Robert Tari
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3, as published
@@ -455,6 +455,8 @@ create_header_state (IndicatorPowerService * self)
 
   g_variant_builder_add (&b, "{sv}", "title", g_variant_new_string (_("Battery")));
 
+  g_variant_builder_add (&b, "{sv}", "tooltip", g_variant_new_string (_("Battery status and power management")));
+
   g_variant_builder_add (&b, "{sv}", "visible",
                          g_variant_new_boolean (should_be_visible (self)));
 
